%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Butcher array
%
% CALL  : B=but(i)
%
% INPUT : i  - Choice of the Butcher array
%                1 - explicit Euler Method explizites Euler-Verfahren
%                2 - modified Euler Method (Collatz Method)
%                3 - Heun Method 
%                4 - Classical Runge-Kutta Method
%
% OUTPUT: B  - Butcher table in the form
%                     [  0       |    0                                  ] 
%                     [alpha_{2} | beta_{2,1}                            ]  
%                 but=[  :       |    :       .                          ]  
%                     [alpha_{s} | beta_{s,1} ... beta_{s,s-1}           ]  
%                     [----------+---------------------------------------]
%                     [          | gamma_{1}  ... gamma_{s-1}  gamma_{s} ]
%
function [B]=exprk(i)

if(i<1|i>4) Error('i should be 1,2,3 or 4'); end;

% explicit Euler
if(i==1) B=[0 0;0 1]; end;
% modified Euler
if(i==2) B=[0 0 0;1/2 1/2 0;0 0 1]; end;
% Heun
if(i==3) B=[0 0 0;1 1 0;0 1/2 1/2]; end;
% classical Runge-Kutta
if(i==4) B=[0 0 0 0 0;1/2 1/2 0 0 0;1/2 0 1/2 0 0;1 0 0 1 0;0 1/6 1/3 1/3 1/6]; end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

