%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Single Shooting Method
% Solving Boundary Value Problem
%
% y'(t)=f(y,t),
% y(a) = ya, y(b) = b,       
%
% CALL  : [h,t,y,s,z]= shooting(funct,but,a,n,y0i,y0,s0i,s0,y1i,y1,N,l,ds,tol)
%
% INPUT : funct - name of the routine which determines the right hand side f(t,y) (Text-String)
%         but   - Butcher array in the form
%                     [  0       |    0                                     ]
%                     [alpha_{2} | beta_{2,1}                               ]  
%                 but=[  :       |    :        .                            ]  
%                     [alpha_{s} | beta_{s,1}  ...  beta_{s,s-1}            ]  
%                     [----------+------------------------------------------]
%                     [          | gamma_{1}   ...  gamma_{s-1}  gamma_{s}  ]
%                 
%         n     - dimension of the problem, i.e, y,f \in R^n,
%                 number of variables in our system,
%                 i.e., if  y_1 = y and  y_2 = y' then n = 2
%         y0i   - vector with information for which variable there is an initial value defined, i.e.,    
%                        y_1(a) = ya1
%                        y_3(a) = ya3  ====> y0i = [1,3,4,6]
%                        y_4(a) = ya4
%                        y_6(a) = ya6
%         y0    - initial values at positions y0i(i), i.e., y0 = [ya1, ya3, ya4, ya6]
%
%         s0i   - vector with information for which variable there is no
%                 initial value given, i.e., since
%                        y_1(a) = ya1
%                        y_3(a) = ya3   there are no values for y_2(a) and y_5(a), so we put y_2(a) = s2 and y_5(a) = s5  ==> s0i = [2,5]
%                        y_4(a) = ya4
%                        y_6(a) = ya6
%         s0    - initial guesses at positions s0i(i), i.e., s0 =[s2,s5] 
%         y1i   - vector with information for which variable there is an
%                 final value defined, i.e.,
%                        y_2(b) = yb2
%                        y_5(b) = yb3  =====>  y1i=[2,5]
%         y1    - final values at positions y1i(i), i.e., y1 = [yb2, yb3]
%         N     - number of steps for IVP solver, see exprk function
%         l     - the length of the interval I = [a, b], a + l = b
%         ds    - difference for approximatinf the Jacobian dF/ds
%         tol   - accuracy of the approximation norm(y(y1i,N+1)-y1,2)<tol
%
% OUTPUT: h     - step size
%         t     - mesh points for IVP solver
%         y     - approximate solution
%         s     - final sequence of starting values
%         z     - number of iterations
%
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This is the part you have to implement
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [h,t,y,s,z]=shooting(funct,but,a,n,y0i,y0,s0i,s0,y1i,y1,N,l,ds,tol)

% maxit - maximal number of iterations for the Newton's method (maxit=50)
maxit=50;                             %maximale Iterationszahl



